textmining.TsujiiC3.EnjuGroupDocumentStream

|  | ## Cheshire3 Object Model: Class EnjuGroupDocumentStream

Package textmining :: Module TsujiiC3 :: Class EnjuGroupDocumentStream

## Class EnjuGroupDocumentStream
source code

Object Tree:

                 object --+
                          |
      configParser.C3Object --+
                              |
    baseObjects.DocumentFactory --+
                                  |
                                 EnjuGroupDocumentStream

Instance Methods

process_record(self, session, rec)
Inherited from `baseObjects.DocumentFactory`: `get_document`, `load` Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### process_record(self, session, rec) | source code